[pve-devel] [PATCH common 1/3] schema: rename storagepair to storage-pair
Fabian Grünbichler
f.gruenbichler at proxmox.com
Fri Nov 5 14:03:45 CET 2021
more consistent with the other options/formats like pve-storage-id
Signed-off-by: Fabian Grünbichler <f.gruenbichler at proxmox.com>
---
Notes:
v2: new
this breaks older qemu-server without the patch adapting to the new name
src/PVE/JSONSchema.pm | 4 ++--
1 file changed, 2 insertions(+), 2 deletions(-)
diff --git a/src/PVE/JSONSchema.pm b/src/PVE/JSONSchema.pm
index 71df690..52b3125 100644
--- a/src/PVE/JSONSchema.pm
+++ b/src/PVE/JSONSchema.pm
@@ -286,9 +286,9 @@ my $verify_idpair = sub {
};
# note: this only checks a single list entry
# when using a storagepair-list map, you need to pass the full parameter to
# parse_idmap
-register_format('storagepair', \&verify_storagepair);
+register_format('storage-pair', \&verify_storagepair);
sub verify_storagepair {
my ($storagepair, $noerr) = @_;
return $verify_idpair->($storagepair, $noerr, 'pve-storage-id');
@@ -286,9 +286,9 @@ my $verify_idpair = sub {
};
# note: this only checks a single list entry
-# when using a storagepair-list map, you need to pass the full parameter to
+# when using a storage-pair-list map, you need to pass the full parameter to
# parse_idmap
--
2.30.2
More information about the pve-devel
mailing list